Started to rescind the name "skin", replacing it with "tool".  Did this in all
the places that normal users will see:

  - command line: --tool=foo (although --skin=foo still works)
  - docs: removed all traces (included renaming coregrind_skins.html to
    coregrind_tools.html)
  - in the usage messages
  - in error messages

Also did in in some places that I judged were unlikely to cause clashes with
existing workspaces:

  - in the header comments of many files (eg. "This file is part of Memcheck, a
    Valgrind tool for...")
  - in the regtests script
  - in the .supp files
  - in AUTHORS
  - in README_MISSING_SYSCALL_OR_IOCTL

Also update the AUTHORS file to mention Jeremy.


git-svn-id: svn://svn.valgrind.org/valgrind/trunk@2027 a5019735-40e9-0310-863c-91ae7b9d1cf9
diff --git a/addrcheck/ac_main.c b/addrcheck/ac_main.c
index e0f2305..5407e13 100644
--- a/addrcheck/ac_main.c
+++ b/addrcheck/ac_main.c
@@ -1,12 +1,12 @@
 
 /*--------------------------------------------------------------------*/
 /*--- The AddrCheck skin: like MemCheck, but only does address     ---*/
 /*--- checking.  No definedness checking.                          ---*/
 /*---                                                    ac_main.c ---*/
 /*--------------------------------------------------------------------*/
 
 /*
-   This file is part of AddrCheck, a lightweight Valgrind skin for
+   This file is part of AddrCheck, a lightweight Valgrind tool for
    detecting memory errors.
 
    Copyright (C) 2000-2003 Julian Seward 
@@ -1193,7 +1193,7 @@
          VG_(message)(Vg_UserMsg,                                       \
             "Warning: Addrcheck: ignoring `%s' request.", what);     \
          VG_(message)(Vg_UserMsg,                                       \
-            "   To honour this request, rerun with --skin=memcheck.");  \
+            "   To honour this request, rerun with --tool=memcheck.");  \
       }                                                                 \
    } while (0)
@@ -1,12 +1,12 @@
 
 /*--------------------------------------------------------------------*/
-/*--- The AddrCheck skin: like MemCheck, but only does address     ---*/
+/*--- The AddrCheck tool: like MemCheck, but only does address     ---*/
 /*--- checking.  No definedness checking.                          ---*/
 /*---                                                    ac_main.c ---*/